@@ -2,7 +2,7 @@ use 5.006;
 
 package WWW::Scripter;
 
-our $VERSION = '0.030';
+our $VERSION = '0.031';
 
 use strict; use warnings; no warnings qw 'utf8 parenthesis bareword';
 
@@ -1629,7 +1629,7 @@ use constant 1.03 our $_const = {
 	cnam => 3,
 	plat => 4,
 };
-{ no strict; delete @{__PACKAGE__.::}{_const => keys %$_const} }
+{ no strict; delete @{__PACKAGE__."::"}{_const => keys %$_const} }
 
 sub new {
 	weaken((my $self = bless[],pop)->[mech] = pop);
